Description Usage Arguments Value See Also Examples
query_snaptron_samples find the metadata for the samples of interest
1 | query_snaptron_samples(database, sample_info)
|
database |
Character scalar. Database of junctions - "srav1", "srav2", "gtex" |
sample_info |
either df outputed from |
list containing df, with each element correponding to sample metadata for 1 junction
For more details on input and output parameters see: http://snaptron.cs.jhu.edu/reftables.html
Sample metadata downloaded from http://snaptron.cs.jhu.edu/data/
1 2 3 | query_snaptron_samples(database = "srav2", sample_info = c(1,2))
query_snaptron_samples(database = "srav2", sample_info = list(c(1, 2), c(3, 4)))
query_snaptron_samples(database = "srav2", sample_info = query_snaptron_junc_output)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.