Description Usage Arguments Value See Also Examples
query_snaptron_junc takes as input the junction co-ordinates and
returns the details of matching junctions found in the snapton database
1 2 | query_snaptron_junc(database, regions, rfilter = NULL,
rfilter_values = NULL, method = "contains", tmp_dir = ".")
|
database |
Character scalar. Database of junctions - "srav1", "srav2", "gtex" |
regions |
Character scalar. Genomic co-ordinates of the junctions you want to query in format - "chr1:1-100" |
rfilter |
Character vector. Filters to use for returned junctions - "length", "strand", "annotated" etc |
rfilter_values |
Character vector. Corresponding to rfilter parameters, need to be prefaced by the type of test or ":" - e.g. "<:5000" or ":1" |
method |
Character scalar. Do you want all junctions within the region or only those precisely matching the start and stop? |
df with details of junctions that match criteria from snaptron
For more details on input and output parameters see: http://snaptron.cs.jhu.edu/reftables.html
1 2 3 4 5 | query_snaptron_junc(database = "gtex", regions = "chr4:89729278-89771396",
rfilter = c("length", "annotated"), rfilter_values = c("<:10000", ":0"))
query_snaptron_junc(database = "srav2",
regions = c("chr4:89729278-89771396", "chr4:89729278-89729407"),
method = "exact", tmp_dir = "/home/dzhang/")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.